@@ -76,14 +76,19 @@ def load(data, func=None, globals=None):
                             CACHE[name] = funct
                             func[mod['module']] = funct
             else:
-                funct = __import__(mod, fromlist=['object'])
-                CACHE[mod] = funct
-                func[mod] = funct
+                funct = get(mod)
+                if funct!=None:
+                    CACHE[mod] = funct
+                    func[mod] = funct
                 
     elif isinstance(data, str):
-        funct = __import__(data, fromlist=['object'])
-        CACHE[data] = funct
-        func[data] = funct
+        if data in CACHE:
+            func[data] = CACHE[data]
+        else:
+            funct = get(data)
+            if funct!=None:
+                CACHE[data] = funct
+                func[data] = funct
 
 #Décharger un module
 def unload(modulename, uncache=False):
@@ -111,15 +116,19 @@ def get(modulename):
         if modulename in CACHE:
             return CACHE[modulename]
 
-    if modulename in sys.modules:
-        return sys.modules[modulename]
-    else:
+    try:
+        funct = __import__(modulename, fromlist=['object'])
+        return funct
+    except:
         try:
-            funct = __import__(modulename, fromlist=['object'])
-            return funct
+            if "." in modulename:
+                modulename = modulename.split(".")
+                funct = __import__(".".join(modulename[:-1]), fromlist=['object'])
+
+                funct = getattr(funct, modulename[-1])
+                return funct
         except:
             return None
-
     return None
 
 #Décorateur pour l'importation de module
